/*
 * Copyright (C) 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.systemui.broadcast

import android.content.BroadcastReceiver
import android.content.IntentFilter
import android.os.Handler
import android.os.Looper
import android.os.UserHandle
import android.util.ArraySet
import android.util.Log
import com.android.systemui.SysuiTestableContext
import com.android.systemui.dump.DumpManager
import java.util.concurrent.Executor

class FakeBroadcastDispatcher(
    context: SysuiTestableContext,
    handler: Handler,
    looper: Looper,
    dumpManager: DumpManager
) : BroadcastDispatcher(context, handler, looper, dumpManager) {

    private val registeredReceivers = ArraySet<BroadcastReceiver>()

    override fun registerReceiverWithHandler(
        receiver: BroadcastReceiver,
        filter: IntentFilter,
        handler: Handler,
        user: UserHandle
    ) {
        registeredReceivers.add(receiver)
    }

    override fun registerReceiver(
        receiver: BroadcastReceiver,
        filter: IntentFilter,
        executor: Executor?,
        user: UserHandle
    ) {
        registeredReceivers.add(receiver)
    }

    override fun unregisterReceiver(receiver: BroadcastReceiver) {
        registeredReceivers.remove(receiver)
    }

    override fun unregisterReceiverForUser(receiver: BroadcastReceiver, user: UserHandle) {
        registeredReceivers.remove(receiver)
    }

    fun cleanUpReceivers(testName: String) {
        registeredReceivers.forEach {
            Log.i(testName, "Receiver not unregistered from dispatcher: $it")
        }
        registeredReceivers.clear()
    }
}